#
# spec file for package fnott
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fnott
Version:        1.7.1
Release:        1.1
Summary:        Lightweight notification daemon for Wayland
License:        MIT
Group:          System/GUI/Other
URL:            https://codeberg.org/dnkl/fnott
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
# https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xb19964fbba09664cc81027ed5bbd4992c116573f
Source2:        %{name}.keyring
BuildRequires:  meson >= 0.58
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scdoc
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fcft) < 4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.0.0
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tllist) >= 1.0.1
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc11
%else
BuildRequires:  gcc >= 8
%endif

%description
Lightweight notification daemon for Wayland.

%prep
%autosetup -p1

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       %{name}
Requires:       zsh

%description    zsh-completion
Zsh command-line completion support for %{name}

%build
%meson \
%if 0%{?suse_version} <= 1600 && 0%{?is_opensuse}
  -Dc_std=c11 \
%endif
  -Db_lto=true
%meson_build

%install
%meson_install

%files
%{_bindir}/fnott
%{_bindir}/fnottctl
%if 0%{?suse_version} > 1600 && 0%{?is_opensuse}
%{_userunitdir}/fnott.service
%endif

%{_mandir}/man1/fnott.1%{?ext_man}
%{_mandir}/man1/fnottctl.1%{?ext_man}
%{_mandir}/man5/fnott.ini.5%{?ext_man}

%dir %{_datadir}/doc/%{name}
%license %{_datadir}/doc/%{name}/LICENSE
%doc %{_datadir}/doc/%{name}/README.md
%doc CHANGELOG.md

%dir %{_sysconfdir}/xdg/%{name}/
%config(noreplace) %{_sysconfdir}/xdg/%{name}/fnott.ini
%{_datadir}/applications/fnott.desktop

%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/%{name}.service

%files zsh-completion
%{_datadir}/zsh/site-functions/_fnott
%{_datadir}/zsh/site-functions/_fnottctl

%changelog
* Sat Feb 15 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 1.7.1:
  * anchor can now be set to center.
  * Nanosvg updated to ea6a6aca009422bba0dbad4c80df6e6ba0c82183
  * fix: Messages sent directly after starting fnott (for example, when
    fnott is auto-activated by D-Bus) not processed until more D-Bus messages
    are received later.
* Sun Jan 19 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Add unpackaged file fnott.service.
* Tue Sep 24 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Completion packages require main package
* Fri Aug  2 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Specfile cleanup
  * %%config macro for config file
* Fri Aug  2 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Set c11 to leap only. confusing workaround
* Fri Aug  2 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.7.0:
  * Log output now respects the [`NO_COLOR`](http://no-color.org/)
    environment variable.
  * `border-radius` configuration option (yes, this means fnott now
    supports rounded corners).
  * Support for linking against a system provided nanosvg library. See
    the new `-Dsystem-nanosvg` meson option. Defaults to `disabled`
    (i.e. use the bundled version).
  * Support for the `x-canonical-private-synchronous` hint.
  * XDG activation support; when triggering an action, fnott attempts to
    retrieve an XDG activation token. This will only succeed if the
    cursor is inside the notification window. The token is then
    signaled over the D-Bus _Notifications_ interface.
  * `fnottctl dismiss-with-default-action`.
  * Implemented the `org.freedesktop.DBus.Introspectable`
    interface. This fixes an issue where e.g. `gdbus` was not able to
    create, or close, notifications.
  * Left clicking a notification now triggers the default action, if
    any, in addition to dismissing the notification. Right click to
    dismiss the notification without trigger the default action.
  * `STRING:image-path` hint that points to either a non-existing file,
    or an invalid image, will now be ignored (instead of removing the
    notification's icon).
  * All notifications are now dismissed
    (i.e. `org.freedesktop.Notifications.NotificationClosed` is
    signaled) when fnott exits.
  * `reason` in the `NotificationClosed` signal being off-by-one.
  * Icons loaded via `image-data` hints being too dark.
  * Not all data being read from the action selection helper, under
    certain circumstances.
* Tue Jul 16 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Add new file to list /usr/share/dbus-1/services/fnott.service
* Tue Jul 16 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.6.0:
  * selection-helper-uses-null-separator=yes|no to fnott.ini. This can be used to e.g. improve handling of action strings with newlines in them.
  * scaling-filter to fnott.ini, allowing you to choose which scaling filter to use when scaling non-SVG notification images. The default is lanczos3.
  * Nanosvg updated to 93ce879dc4c04a3ef1758428ec80083c38610b1f
  * D-Bus service file for starting automatically
  * Systemd unit file
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add package sig and developer keyring
- Remove 0001-memfd-noexec-seal.patch (Fixed upstream)
- Update to 1.5.0
  Added:
  * docs meson option
  * pause and unpause commands to temporarily disable or re-enable
    notifications.
  * Support for fractional scaling (wp_fractional_scale_v1).
  * Support for preferred buffer scale (wl_compositor >= 6).
  * Support for server side cursors (wp_cursor_shape_v1).
  Changed:
  * Fnott now requires wayland-protocols >= 1.32.
  * Minimum required meson version is now 0.59.
  * Move example config to <sysconfdir>/xdg/fnott.ini.
  * dpi-aware no longer accepts the value auto, and the default
    value is now no.
  Removed:
  * dpi-aware=auto
* Fri Oct 13 2023 Soc Virnyl Estela <socvirnyl.estela@uncomfyhalomacro.pl>
- Add 0001-memfd-noexec-seal.patch
  * newer kernels introduced MFD_NOEXEC_SEAL. Linux kernels older than
    6.3 will crash fnott because they will reject memfd_create() calls that set it.
    This patch fixes it by testing first if it works with the new MFD_NOEXEC_SEAL
    and then retry without it.
* Tue Jul 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove the following patches as they are already part of the new release
  * 0000-unreleased-changelog.patch
  * 0001-decoded-len-unused.patch
  * 0002-include-stdc-predef.patch
  * 0003-clang-fixes-on-changelog.patch
  * 0004-pkgbuild-on-changelog.patch
  * 0005-clang-plus-notification-stack-fix.patch
- Update to 1.4.1
  * Compilation errors with clang 15.x
  * Notifications initially positioned outside the screen not being visible after being moved up in the notification stack.
* Fri Jun 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add the following patches:
  * 0000-unreleased-changelog.patch
  * 0001-decoded-len-unused.patch
  * 0002-include-stdc-predef.patch
  * 0003-clang-fixes-on-changelog.patch
  * 0004-pkgbuild-on-changelog.patch
  * 0005-clang-plus-notification-stack-fix.patch (originally as 0000-clang-plus-notification-stack-fix.patch)
- These patches bring some small improvements and fixes
* Fri Jun 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-clang-plus-notification-stack-fix.patch
  * Notifications initially positioned outside the screen not being
  * visible after being moved up in the notification stack.
* Mon Apr  3 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.4.0
  * Added idle-timeout option to specify the amount of time you need to be idle before notifications are prevented from timing out (#16).
  * Added icon option, to specify icon to use when none is provided by the notification itself (#82).
  * Support for image-path hints (#84).
  * dpi-aware=no|yes|auto option (#80).
  * Changed Default value of max-width and max-height is now 0 (unlimited).
  * When determining initial font size, do FontConfig config substitution if the user-provided font pattern has no {pixel}size option (#1287).
  * Fixed file:// URIs, in icon paths (#84)
  * Replace ID being ignored if there were no prior notification with that ID.
  * Wayland protocol violation when output scaling was enabled.
  * Notification expiration (timeout) and dismissal are now deferred while the action selection helper is running (#90).
- cleaned up specfile
* Fri Dec  2 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update specfile
- Change to c11 standard to comply with latest on leap
* Fri Aug 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.3.0:
  * Added:
  - Support for a “progress” hints, notify-send -h int:value:20 ..., (#51).
  - title-format, summary-format and body-format options, allowing you to customize the rendered strings. In this release, the %%a, %%s, %%b and %%%% formatters, as well as \n, are recognized. (#39).
  - Added configuration option layer to specify the layer on which notifications are displayed. Values include background, top, bottom, and overlay (#71).
  * Changed:
  - Minimum required meson version is now 0.58.
  - Notification text is now truncated instead of running into, and past, the vertical padding (#52).
  - All color configuration options have been changed from (A)RGB (i.e. ARGB, where the alpha component is optional), to RGBA. This means all color values must be specified with 8 digits (#47).
  * Removed:
  - $XDG_CONFIG_HOME/fnottrc and ~/.config/fnottrc. Use $XDG_CONFIG_HOME/fnott/fnott.ini (defaulting to ~/.config/fnott/fnott.ini) instead (#7).
  * Fixed:
  - Scale not being applied to the notification’s size when first instantiated (#54).
  - Fallback to /etc/xdg if XDG_CONFIG_DIRS is unset.
  - Icon lookup is now better at following the XDG specification (#64).
  - Setting max-width and/or max-height to 0 no longer causes fnott to crash. Instead, a zero max-width/height means there is no limit (#66).
* Mon Mar  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- use released tarball with source URL
* Sat Feb 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec
